<?php

namespace App\Entity;

use App\Repository\MachineRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use Stringable;
use Symfony\Bridge\Doctrine\Validator\Constraints\UniqueEntity;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * A machine
 */
#[ORM\Entity(repositoryClass: MachineRepository::class)]
#[UniqueEntity(fields: ['name'], message: 'Il existe déjà une machine avec ce nom')]
class Machine implements Stringable {
    use TBaseEntity;
    use TNamedEntity;

    /**
     * @var string|null The label for the first extra information
     */
    #[ORM\Column(length: 255, nullable: true)]
    #[Assert\NotBlank(message: 'Veuillez saisir un nom d\'information complémentaire n° 1', allowNull: true)]
    private ?string $labelExtraInfo1 = null;
    /**
     * @var string|null The label for the second extra information
     */
    #[ORM\Column(length: 255, nullable: true)]
    #[Assert\NotBlank(message: 'Veuillez saisir un nom d\'information complémentaire n° 2', allowNull: true)]
    private ?string $labelExtraInfo2 = null;

    /**
     * @var Collection<int, Recipe> The recipes
     */
    #[ORM\OneToMany(targetEntity: Recipe::class, mappedBy: 'machine', orphanRemoval: true)]
    #[Assert\Valid]
    private Collection $recipes;

    /**
     * Initialization
     */
    public function __construct () {
        $this->recipes = new ArrayCollection();
    }

    /**
     * The label for the first extra information
     *
     * @return string|null The label for the first extra information
     */
    public function getLabelExtraInfo1 (): ?string {
        return $this->labelExtraInfo1;
    }
    /**
     * Set the label for the first extra information
     *
     * @param string|null $labelExtraInfo1 The label for the first extra information
     *
     * @return $this
     */
    public function setLabelExtraInfo1 (?string $labelExtraInfo1): static {
        $this->labelExtraInfo1 = $labelExtraInfo1;

        return $this;
    }

    /**
     * The label for the second extra information
     *
     * @return string|null The label for the second extra information
     */
    public function getLabelExtraInfo2 (): ?string {
        return $this->labelExtraInfo2;
    }
    /**
     * Set the label for the second extra information
     *
     * @param string|null $labelExtraInfo2 The label for the second extra information
     *
     * @return $this
     */
    public function setLabelExtraInfo2 (?string $labelExtraInfo2): static {
        $this->labelExtraInfo2 = $labelExtraInfo2;

        return $this;
    }

    /**
     * The recipes
     *
     * @return Collection<int, Recipe> The recipes
     */
    public function getRecipes (): Collection {
        return $this->recipes;
    }
    /**
     * Add a recipe
     *
     * @param Recipe $recipe The recipe
     *
     * @return $this
     */
    public function addRecipe (Recipe $recipe): static {
        if (!$this->recipes->contains($recipe)) {
            $this->recipes->add($recipe);
            $recipe->setMachine($this);
        }

        return $this;
    }
    /**
     * Remove a recipe
     *
     * @param Recipe $recipe The recipe
     *
     * @return $this
     */
    public function removeRecipe (Recipe $recipe): static {
        if ($this->recipes->removeElement($recipe)) {
            // set the owning side to null (unless already changed)
            if ($recipe->getMachine() === $this) {
                $recipe->setMachine(null);
            }
        }

        return $this;
    }
}
